import React, { useState, useEffect, useRef } from 'react';
import ProTable from '@ant-design/pro-table';
import { Form, Input, Select, InputNumber, TreeSelect, message, Button, Modal, Radio, Upload, Switch } from 'antd';
import quickAPI from "../../service";
import indexStyles from "../../index.less";
import StepsButton from "../StepsButton";

/**
 * 配方配置
 * @returns 
 */
const BomConfig = (props) => {

    const [editBomForm] = Form.useForm();

    const optionsWithDisabled = [
        {
            label: '新建配方',
            value: true,
        },
        {
            label: '选择配方',
            value: false,
        }
    ];

    const [isCreate, setIsCreate] = useState(props.bomConfig.id ? false : true);

    const onChangeState = ({ target: { value } }) => {
        setIsCreate(value);
        let emptyObj = {
            id: "",
            code: "",
            name: "",
            bomTypeList: [],
            sort: 0
        }
        props.onFinishForm('bomConfig', emptyObj);
        editBomForm.setFieldsValue(emptyObj);
        setSelectRowKeys([]);
        setSelectedRows([]);
    }

    const onFinish = (values) => {
        props.onFinishForm('bomConfig', values, true);
    }

    const columns = [
        {
            title: '配方编码',
            dataIndex: 'code',
            hideInForm: true,
            hideInSearch: true,
        },
        {
            title: '配方名称',
            dataIndex: 'name',
            hideInForm: true,
            hideInSearch: true,
        }
    ];

    const [currentPage, setCurrentPage] = useState(0);
    const [pageSize, setPageSize] = useState(5);

    const [selectedRowsState, setSelectedRows] = useState(props.bomConfig.id ? [props.bomConfig] : []);
    const [selectedRowKeys, setSelectRowKeys] = useState(props.bomConfig.id ? [props.bomConfig.id] : []);
    //配方类型
    const [bomtype, setBomtype] = useState([]);
    //是否展示配方弹窗
    const [isShowBomModal, setIsShowBomModal] = useState(false);

    /**
     * 获取菜谱分类
     */
    const onFetchBomType = async () => {
        const response = await quickAPI.GetBomTypePage({
            current: 1,
            pagesize: 1000
        });
        if (response.statusCode === 200) {
            setBomtype(response.data.data);
        }
    }

    useEffect(() => {
        onFetchBomType();
    }, []);

    return <>
        <div className={indexStyles.choose_change_state}>
            <Radio.Group
                options={optionsWithDisabled}
                onChange={onChangeState}
                value={isCreate}
                optionType="button"
                buttonStyle="solid"
            />
        </div>

        <div className={indexStyles.common_row}>
            <Form
                labelCol={{ span: 4 }}
                layout="horizontal"
                preserve={false}
                initialValues={props.bomConfig}
                onFinish={onFinish}
                style={{ width: '600px', marginRight: '30px' }}
                form={editBomForm}
            >
                <Form.Item name="id" hidden={true}>
                    <Input />
                </Form.Item>
                <Form.Item name="code" label="配方编码" rules={[{ required: true }]} >
                    <Input placeholder="配方编码" disabled={!isCreate || props.bomConfig.id} />
                </Form.Item>
                <Form.Item name="name" label="配方名称" rules={[{ required: true }]}>
                    <Input placeholder="配方名称" disabled={!isCreate || props.bomConfig.id} />
                </Form.Item>

                <div className={indexStyles.add_row_content}>
                    <Form.Item name="bomTypeList" label="配方类型" rules={[{ required: true }]}>
                        <Select
                            disabled={!isCreate || props.bomConfig.id}
                            style={{ width: '75%' }}
                            mode="multiple"
                            allowClear >
                            {bomtype.map((item, index) => {
                                return (
                                    <Select.Option index={item.id} value={item.id} key={item.id}>
                                        {item.name}
                                    </Select.Option>
                                );
                            })}
                        </Select>
                    </Form.Item>
                    <Button disabled={!isCreate || props.bomConfig.id} type="primary" className={indexStyles.add_row_btn} onClick={() => setIsShowBomModal(true)} >添加配方类型</Button>
                </div>

                <Form.Item name="isMain" label="配方类型" >
                    <Switch disabled={!isCreate || props.bomConfig.id} checkedChildren="主料" unCheckedChildren="辅料" />
                </Form.Item>
                <Form.Item name="sort" label="排序" rules={[{ required: true }]}>
                    <InputNumber placeholder="排序" min={1} disabled={!isCreate || props.bomConfig.id} />
                </Form.Item>
                <Form.Item>
                    <StepsButton current={props.current} steps={props.steps} prev={props.prev}></StepsButton>
                </Form.Item>
            </Form>

            <Modal
                title="新建配方类型"
                width={640}
                bodyStyle={{ padding: '32px 40px 48px' }}
                visible={isShowBomModal}
                footer={null}
                onCancel={() => {
                    setIsShowBomModal(false);
                }}
                destroyOnClose
                maskClosable={false}
            >
                <Form
                    layout="vertical"
                    preserve={false}
                    initialValues={props?.values}
                    onFinish={async (values) => {
                        const response = await quickAPI.CreateBomType(values);
                        if (response.data) {
                            message.success('配方类别添加成功');
                            setIsShowBomModal(false);
                            onFetchBomType();
                        } else {
                            message.error(response.errors || '配方类别添加失败');
                        }
                    }}
                >
                    <Form.Item name="id" hidden={true}>
                        <Input />
                    </Form.Item>
                    <Form.Item name="name" label="配方类型名称" rules={[{ required: true, max: 64, whitespace: true }]}>
                        <Input placeholder="请输入配方类型名称" />
                    </Form.Item>
                    <Form.Item
                        name="pertain"
                        label="归属"
                        defaultValue={props?.values?.pertain}
                        rules={[{ required: true, message: '请选择类型归属' }]}  >
                        <Select placeholder="请选择类型归属">
                            <Option value="1">无</Option>
                            <Option value="2">TMC </Option>
                        </Select>
                    </Form.Item>
                    <Form.Item
                        name="status"
                        label="状态"
                        defaultValue={props?.values?.status}
                        rules={[{ required: true, message: '请选择状态' }]}
                    >
                        <Select placeholder="请选择状态">
                            <Option value="0">正常</Option>
                            <Option value="1">停用</Option>
                        </Select>
                    </Form.Item>
                    <Form.Item>
                        <Button type="primary" htmlType="submit">
                            保存
                        </Button>
                    </Form.Item>
                </Form>
            </Modal>

            {
                !isCreate && <ProTable
                    headerTitle="配方列表"
                    rowKey="id"
                    pagination={{
                        current: currentPage,
                        pageSize: pageSize,
                        onChange: (page, pageSize) => {
                            setCurrentPage(page);
                            setPageSize(pageSize);
                        }
                    }}
                    search={false}
                    //数据绑定
                    request={async (params) => {
                        var goodsBomsData = [];
                        var total = 0;
                        await quickAPI.GetBomPage(params).then((r) => {
                            goodsBomsData = r.data.data;
                            total = r.data.total;
                        });
                        return {
                            data: goodsBomsData,
                            success: true,
                            total: total,
                        };
                    }}
                    columns={columns}
                    rowSelection={{
                        type: 'radio',
                        onChange: (selectedRowKeys, selectedRows) => {
                            setSelectRowKeys(selectedRowKeys);
                            setSelectedRows(selectedRows);
                            if (selectedRows.length > 0) {
                                props.onFinishForm('bomConfig', selectedRows[0]);
                                editBomForm.setFieldsValue(selectedRows[0]);
                            } else {
                                let emptyObj = {
                                    id: "",
                                    code: "",
                                    name: "",
                                    bomTypeList: [],
                                    sort: 0
                                }
                                editBomForm.setFieldsValue(emptyObj);
                                props.onFinishForm('bomConfig', emptyObj);
                            }
                        },
                        selectedRowKeys: selectedRowKeys
                    }}
                />
            }
        </div>
    </>
}

export default BomConfig;